@@ -42,6 +42,8 @@ class Device:
         self.path = path
         self.handle = handle
         self.product_id = None
+        self.hidpp_short = info.hidpp_short if info else None
+        self.hidpp_long = info.hidpp_long if info else None
 
         if receiver:
             assert number > 0 and number <= 15  # some receivers have devices past their max # of devices
@@ -114,7 +116,7 @@ class Device:
                 # assert link_notification.address == (0x04 if unifying else 0x03)
                 kind = ord(link_notification.data[0:1]) & 0x0F
                 # get 27Mhz wpid and set kind based on index
-                if receiver.ex100_27mhz_wpid_fix:  # 27 Mhz receiver
+                if receiver.receiver_kind == '27Mhz':  # 27 Mhz receiver
                     self.wpid = '00' + _strhex(link_notification.data[2:3])
                     kind = self.get_kind_from_index(number, receiver)
                 self._kind = _hidpp10.DEVICE_KIND[kind]
@@ -172,7 +174,9 @@ class Device:
     @property
     def protocol(self):
         if not self._protocol and self.online:
-            self._protocol = _base.ping(self.handle or self.receiver.handle, self.number, long_message=self.bluetooth)
+            self._protocol = _base.ping(
+                self.handle or self.receiver.handle, self.number, long_message=self.bluetooth or self.hidpp_short is False
+            )
             # if the ping failed, the peripheral is (almost) certainly offline
             self.online = self._protocol is not None
 
@@ -359,11 +363,14 @@ class Device:
             battery_feature = self.persister.get('_battery', None) if self.persister else None
             if battery_feature != 0:
                 result = _hidpp20.get_battery(self, battery_feature)
-                if result:
+                try:
                     feature, level, next, status, voltage = result
                     if self.persister and battery_feature is None:
                         self.persister['_battery'] = feature
                     return level, next, status, voltage
+                except Exception:
+                    if self.persister and battery_feature is None:
+                        self.persister['_battery'] = result
 
     def enable_connection_notifications(self, enable=True):
         """Enable or disable device (dis)connection notifications on this
@@ -427,7 +434,7 @@ class Device:
                 request_id,
                 *params,
                 no_reply=no_reply,
-                long_message=self.bluetooth or self.protocol >= 2.0,
+                long_message=self.bluetooth or self.hidpp_short is False or self.protocol >= 2.0,
                 protocol=self.protocol
             )
 
