@@ -259,7 +259,7 @@ class FeaturesArray(dict):
                     _log.warn('FEATURE_SET found, but failed to read features count')
                     return False
                 else:
-                    self.count = ord(count[:1])
+                    self.count = ord(count[:1]) + 1  # ROOT feature not included in count
                     self[FEATURE.ROOT] = 0
                     self[FEATURE.FEATURE_SET] = fs_index
                     return True
@@ -1318,12 +1318,12 @@ def decipher_battery_voltage(report):
 
 
 def get_adc_measurement(device):
-    try:  # this feature call has been known to produce errors so be extra cautious
+    try:  # this feature call produces an error for headsets that are connected but inactive
         report = feature_request(device, FEATURE.ADC_MEASUREMENT)
         if report is not None:
             return decipher_adc_measurement(report)
     except FeatureCallError:
-        return None
+        return FEATURE.ADC_MEASUREMENT if FEATURE.ADC_MEASUREMENT in device.features else None
 
 
 def decipher_adc_measurement(report):
@@ -1347,7 +1347,8 @@ battery_functions = {
 
 
 def get_battery(device, feature):
-    """Return battery information - feature, approximate level, next, charging, voltage"""
+    """Return battery information - feature, approximate level, next, charging, voltage
+    or battery feature if there is one but it is not responding or None for no battery feature"""
     if feature is not None:
         battery_function = battery_functions.get(feature, None)
         if battery_function:
@@ -1359,7 +1360,7 @@ def get_battery(device, feature):
             result = battery_function(device)
             if result:
                 return result
-    return 0, None, None, None, None
+    return 0
 
 
 def get_keys(device):
